RtcChannel class
The RtcChannel class.
- Mixed-in types
Properties
Methods
-
addInjectStreamUrl(
String url, LiveInjectStreamConfig config) → Future< void> -
Injects an online media stream to a ChannelProfile.LiveBroadcasting channel.
override
-
addPublishStreamUrl(
String url, bool transcodingEnabled) → Future< void> -
Publishes the local stream to the CDN.
override
-
adjustUserPlaybackSignalVolume(
int uid, int volume) → Future< void> -
Adjusts the playback volume of a specified remote user.
override
-
createDataStream(
bool reliable, bool ordered) → Future< int?> -
Creates a data stream.
override
-
destroy(
) → Future< void> -
Destroys the RtcChannel instance.
override
-
enableEncryption(
bool enabled, EncryptionConfig config) → Future< void> -
Enables/Disables the built-in encryption.
override
-
getCallId(
) → Future< String?> -
Gets the current call ID.
override
-
getConnectionState(
) → Future< ConnectionStateType> -
Gets the connection state of the SDK.
override
-
joinChannel(
String token, String optionalInfo, int optionalUid, ChannelMediaOptions options) → Future< void> -
Joins the channel with a user ID.
override
-
joinChannelWithUserAccount(
String token, String userAccount, ChannelMediaOptions options) → Future< void> -
Joins a channel with the user account.
override
-
leaveChannel(
) → Future< void> -
Leaves the current channel.
override
-
muteAllRemoteAudioStreams(
bool muted) → Future< void> -
Stops/Resumes receiving all remote audio streams.
override
-
muteAllRemoteVideoStreams(
bool muted) → Future< void> -
Stops/Resumes receiving all remote video streams.
override
-
muteRemoteAudioStream(
int uid, bool muted) → Future< void> -
Stops/Resumes receiving the audio stream of the specified user.
override
-
muteRemoteVideoStream(
int uid, bool muted) → Future< void> -
Stops/Resumes receiving the video stream of the specified user.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publish(
) → Future< void> -
Publishes the local stream to the channel.
override
-
registerMediaMetadataObserver(
) → Future< void> -
Registers the metadata observer.
override
-
removeInjectStreamUrl(
String url) → Future< void> -
Removes the injected online media stream from a ChannelProfile.LiveBroadcasting channel.
override
-
removePublishStreamUrl(
String url) → Future< void> -
Removes an RTMP stream from the CDN.
override
-
renewToken(
String token) → Future< void> -
Renews the token when the current token expires.
override
-
sendMetadata(
String metadata) → Future< void> -
Sends the metadata.
override
-
sendStreamMessage(
int streamId, String message) → Future< void> -
Sends the data stream message.
override
-
setClientRole(
ClientRole role) → Future< void> -
Sets the role of a user.
override
-
setDefaultMuteAllRemoteAudioStreams(
bool muted) → Future< void> -
Sets whether to receive all remote audio streams by default.
override
-
setDefaultMuteAllRemoteVideoStreams(
bool muted) → Future< void> -
Sets whether to receive all remote video streams by default.
override
-
setEncryptionMode(
EncryptionMode encryptionMode) → Future< void> -
Sets the built-in encryption mode.
override
-
setEncryptionSecret(
String secret) → Future< void> -
Enables built-in encryption with an encryption password before joining a channel.
override
-
setEventHandler(
RtcChannelEventHandler handler) → void - Sets the channel event handler.
-
setLiveTranscoding(
LiveTranscoding transcoding) → Future< void> -
Sets the video layout and audio settings for CDN live.
override
-
setMaxMetadataSize(
int size) → Future< void> -
Sets the maximum size of the metadata.
override
-
setRemoteDefaultVideoStreamType(
VideoStreamType streamType) → Future< void> -
Sets the default video-stream type of the remote video stream when the remote user sends dual streams.
Parameter
streamTypeSets the default video-stream type. See VideoStreamType.override -
setRemoteUserPriority(
int uid, UserPriority userPriority) → Future< void> -
Sets the priority of a remote user's media stream.
override
-
setRemoteVideoStreamType(
int uid, VideoStreamType streamType) → Future< void> -
Sets the video stream type of the remote video stream when the remote user sends dual streams.
override
-
setRemoteVoicePosition(
int uid, double pan, double gain) → Future< void> -
Sets the sound position of a remote user.
override
-
startChannelMediaRelay(
ChannelMediaRelayConfiguration channelMediaRelayConfiguration) → Future< void> -
Starts to relay media streams across channels.
override
-
stopChannelMediaRelay(
) → Future< void> -
Stops the media stream relay.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unpublish(
) → Future< void> -
Stops publishing a stream to the channel.
override
-
unregisterMediaMetadataObserver(
) → Future< void> -
Unregisters the metadata observer.
override
-
updateChannelMediaRelay(
ChannelMediaRelayConfiguration channelMediaRelayConfiguration) → Future< void> -
Updates the channels for media relay.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
String channelId) → Future< RtcChannel> - Creates and gets an RtcChannel instance.
-
destroyAll(
) → void - Destroys all RtcChannel instance.